@@ -280,12 +280,18 @@ class String(TypedField):
 
 class Function(Field):
     """
-    A function. Note that this can't be any callable (it can't be a class, for example), but a real function
+    A function or method. Note that this can't be any callable (it can't be a class, for example), but a real function
     """
 
+    _bound_method_type = type(Field().__init__)
+
     def __set__(self, instance, value):
         def is_function(f):
-            return type(f) == type(lambda x: x) or type(f) == type(open)
+            return type(f) in {
+                type(lambda x: x),
+                type(open),
+                Function._bound_method_type,
+            }
 
         def err_prefix():
             return (
@@ -353,7 +359,7 @@ class Positive(Number):
 
     def __set__(self, instance, value):
         if value <= 0:
-            raise ValueError("{}: Must be positive".format(self._name))
+            raise ValueError("{}: Got {}; Expected a positive number".format(self._name, value))
         super().__set__(instance, value)
 
 
