@@ -378,7 +378,10 @@ def construct_fields_map(
         )
         process = False
         processed_input = None
-        if converted_key in input_dict and key not in mapper:
+        if key in input_dict and key not in mapper:
+            processed_input = input_dict[key]
+            process = True
+        elif converted_key in input_dict and key not in mapper:
             processed_input = input_dict[converted_key]
             process = True
         elif key in mapper:
@@ -473,16 +476,18 @@ def deserialize_structure_internal(
             "{}: Expected a dictionary; Got {}".format(name, wrap_val(the_dict))
         )
 
+    converted_snake_case_if_required = {k: _convert_to_snake_case_if_required(
+                    k, camel_case_convert=camel_case_convert
+                ) for k in the_dict}
+
     kwargs = dict(
         [
             (
-                _convert_to_snake_case_if_required(
-                    k, camel_case_convert=camel_case_convert
-                ),
+                converted_snake_case_if_required[k],
                 v,
             )
             for k, v in the_dict.items()
-            if k not in field_by_name and keep_undefined
+            if converted_snake_case_if_required[k] not in field_by_name and keep_undefined
         ]
     )
     kwargs.update(
